pub struct StripeClient { /* private fields */ }Implementations
Sourceimpl StripeClient
impl StripeClient
Sourcepub async fn list_subscriptions_all(
&self,
params: Value,
) -> Result<Value, StripeApiError>
pub async fn list_subscriptions_all( &self, params: Value, ) -> Result<Value, StripeApiError>
List every subscription page for params and return a single merged list object.
Sourcepub async fn list_subscription_schedules_all(
&self,
params: Value,
) -> Result<Value, StripeApiError>
pub async fn list_subscription_schedules_all( &self, params: Value, ) -> Result<Value, StripeApiError>
List every subscription schedule page for params and return a single merged list object.
Sourcepub async fn list_customers_all(
&self,
params: Value,
) -> Result<Value, StripeApiError>
pub async fn list_customers_all( &self, params: Value, ) -> Result<Value, StripeApiError>
List every customer page for params and return a single merged list object.
Sourcepub async fn find_customer_from_search<F>(
&self,
query: &str,
predicate: F,
) -> Result<Option<Value>, StripeApiError>
pub async fn find_customer_from_search<F>( &self, query: &str, predicate: F, ) -> Result<Option<Value>, StripeApiError>
Walk customer search pages until predicate matches or the search is exhausted.
Sourcepub async fn find_customer<F>(
&self,
params: Value,
predicate: F,
) -> Result<Option<Value>, StripeApiError>
pub async fn find_customer<F>( &self, params: Value, predicate: F, ) -> Result<Option<Value>, StripeApiError>
Walk customer list pages until predicate matches or the list is exhausted.
Sourcepub async fn find_subscription<F>(
&self,
params: Value,
predicate: F,
) -> Result<Option<Value>, StripeApiError>
pub async fn find_subscription<F>( &self, params: Value, predicate: F, ) -> Result<Option<Value>, StripeApiError>
Walk subscription list pages until predicate matches or the list is exhausted.
Sourcepub async fn find_subscription_schedule<F>(
&self,
params: Value,
predicate: F,
) -> Result<Option<Value>, StripeApiError>
pub async fn find_subscription_schedule<F>( &self, params: Value, predicate: F, ) -> Result<Option<Value>, StripeApiError>
Walk subscription schedule list pages until predicate matches or the list is exhausted.
Sourceimpl StripeClient
impl StripeClient
pub fn new(secret_key: impl Into<String>) -> Self
pub fn with_transport( secret_key: impl Into<String>, transport: Arc<dyn StripeTransport>, ) -> Self
pub fn with_api_base(self, api_base: impl Into<String>) -> Self
pub fn api_version(self, api_version: impl Into<String>) -> Self
pub async fn create_customer( &self, params: Value, ) -> Result<Value, StripeApiError>
pub async fn update_customer( &self, customer_id: &str, params: Value, ) -> Result<Value, StripeApiError>
pub async fn retrieve_customer( &self, customer_id: &str, ) -> Result<Value, StripeApiError>
pub async fn search_customers( &self, query: &str, ) -> Result<Value, StripeApiError>
pub async fn list_customers( &self, params: Value, ) -> Result<Value, StripeApiError>
pub async fn retrieve_price( &self, price_id: &str, ) -> Result<Value, StripeApiError>
pub async fn list_prices(&self, params: Value) -> Result<Value, StripeApiError>
pub async fn price_by_lookup_key( &self, lookup_key: &str, ) -> Result<Value, StripeApiError>
pub async fn create_checkout_session( &self, params: Value, ) -> Result<Value, StripeApiError>
pub async fn retrieve_checkout_session( &self, session_id: &str, ) -> Result<Value, StripeApiError>
pub async fn create_billing_portal_session( &self, params: Value, ) -> Result<Value, StripeApiError>
pub async fn list_subscriptions( &self, params: Value, ) -> Result<Value, StripeApiError>
pub async fn retrieve_subscription( &self, subscription_id: &str, ) -> Result<Value, StripeApiError>
pub async fn update_subscription( &self, subscription_id: &str, params: Value, ) -> Result<Value, StripeApiError>
pub async fn create_subscription_schedule( &self, params: Value, ) -> Result<Value, StripeApiError>
pub async fn list_subscription_schedules( &self, params: Value, ) -> Result<Value, StripeApiError>
pub async fn retrieve_subscription_schedule( &self, schedule_id: &str, ) -> Result<Value, StripeApiError>
pub async fn update_subscription_schedule( &self, schedule_id: &str, params: Value, ) -> Result<Value, StripeApiError>
pub async fn release_subscription_schedule( &self, schedule_id: &str, ) -> Result<Value, StripeApiError>